import * as react_jsx_runtime from 'react/jsx-runtime';
import { NFTCollectionViewProps, NFTDetailProps, Crossmint, UIConfig } from '@crossmint/common-sdk-base';
import { CrossmintEmbeddedCheckoutProps, CrossmintPayButtonProps, CrossmintEmbeddedCheckoutV3Props } from '@crossmint/client-sdk-base';
export { CrossmintEvent, CrossmintEventMap, CrossmintEvents, useCrossmintEvents } from '@crossmint/client-sdk-base';
import * as react from 'react';
import { MouseEvent, CSSProperties, ReactNode } from 'react';
import * as _crossmint_client_sdk_smart_wallet from '@crossmint/client-sdk-smart-wallet';
import { EVMSmartWallet, SmartWalletError, WalletParams, EVMSmartWalletChain } from '@crossmint/client-sdk-smart-wallet';
export { AdminAlreadyUsedError, AdminMismatchError, Chain, ConfigError, EVMSendTransactionError, EVMSendTransactionExecutionRevertedError, EVMSmartWallet, PasskeyIncompatibleAuthenticatorError, PasskeyMismatchError, PasskeyPromptError, PasskeyRegistrationError, PasskeySigner, SmartWalletError, SmartWalletsNotEnabledError, UserWalletAlreadyCreatedError } from '@crossmint/client-sdk-smart-wallet';
import * as _crossmint_common_sdk_auth from '@crossmint/common-sdk-auth';
import { AuthMaterialWithUser, SDKExternalUser } from '@crossmint/common-sdk-auth';
import { CrossmintAuthService } from '@crossmint/client-sdk-auth';

declare function CrossmintNFTCollectionView(props: NFTCollectionViewProps): react_jsx_runtime.JSX.Element;

declare function CrossmintNFTDetail(props: NFTDetailProps): react_jsx_runtime.JSX.Element;

declare function CrossmintPaymentElement(props: CrossmintEmbeddedCheckoutProps): react_jsx_runtime.JSX.Element;

type CrossmintPayButtonReactProps = CrossmintPayButtonProps & {
    onClick?: (e: MouseEvent<HTMLButtonElement>) => void;
    style?: CSSProperties;
};
declare function CrossmintPayButton(buttonProps: CrossmintPayButtonReactProps): react_jsx_runtime.JSX.Element;

declare function CrossmintEmbeddedCheckout_Alpha(props: CrossmintEmbeddedCheckoutV3Props): react_jsx_runtime.JSX.Element;

interface CrossmintContext {
    crossmint: Crossmint;
    setJwt: (jwt: string | undefined) => void;
    setRefreshToken: (refreshToken: string | undefined) => void;
}
declare function CrossmintProvider({ children, apiKey, overrideBaseUrl, }: Omit<Crossmint, "jwt"> & {
    children: ReactNode;
}): react_jsx_runtime.JSX.Element;
declare function useCrossmint(missingContextMessage?: string): CrossmintContext;

interface CrossmintCheckoutContext {
    order?: any;
    orderClientSecret?: string;
}
declare function CrossmintCheckoutProvider({ children }: {
    children: ReactNode;
}): react_jsx_runtime.JSX.Element;
declare function useCrossmintCheckout(): CrossmintCheckoutContext;

type WalletStatus = "not-loaded" | "in-progress" | "loaded" | "loading-error";
type WalletContext = {
    status: WalletStatus;
    wallet?: EVMSmartWallet;
    error?: SmartWalletError;
    getOrCreateWallet: (config?: Pick<WalletConfig, "signer" | "type">) => Promise<{
        startedCreation: boolean;
        reason?: string;
    }>;
    clearWallet: () => void;
};
declare const WalletContext: react.Context<WalletContext>;
type WalletConfig = WalletParams & {
    type: "evm-smart-wallet";
};
declare function CrossmintWalletProvider({ children, defaultChain, showWalletModals, // enabled by default
appearance, }: {
    children: ReactNode;
    defaultChain: EVMSmartWalletChain;
    showWalletModals?: boolean;
    appearance?: UIConfig;
}): react_jsx_runtime.JSX.Element;

declare function useWallet(): {
    status: "not-loaded" | "in-progress" | "loaded" | "loading-error";
    wallet?: _crossmint_client_sdk_smart_wallet.EVMSmartWallet;
    error?: _crossmint_client_sdk_smart_wallet.SmartWalletError;
    getOrCreateWallet: (config?: Pick<WalletConfig, "signer" | "type">) => Promise<{
        startedCreation: boolean;
        reason?: string;
    }>;
    clearWallet: () => void;
};

declare function useAuth(): {
    login: () => void;
    logout: () => void;
    jwt?: string;
    refreshToken?: string;
    user?: _crossmint_common_sdk_auth.SDKExternalUser;
    status: "in-progress" | "logged-in" | "logged-out";
    getUser: () => void;
};

type UseAuthTokenRefreshProps = {
    crossmintAuthService: CrossmintAuthService;
    setAuthMaterial: (authMaterial: AuthMaterialWithUser) => void;
    logout: () => void;
};
declare function useRefreshToken({ crossmintAuthService, setAuthMaterial, logout }: UseAuthTokenRefreshProps): void;

type CrossmintAuthWalletConfig = {
    defaultChain: EVMSmartWalletChain;
    createOnLogin: "all-users" | "off";
    type: "evm-smart-wallet";
    showWalletModals?: boolean;
};
type LoginMethod = "email" | "google" | "farcaster";
type CrossmintAuthProviderProps = {
    embeddedWallets?: CrossmintAuthWalletConfig;
    appearance?: UIConfig;
    children: ReactNode;
    loginMethods?: LoginMethod[];
};
type AuthStatus = "logged-in" | "logged-out" | "in-progress";
type AuthContextType = {
    login: () => void;
    logout: () => void;
    jwt?: string;
    refreshToken?: string;
    user?: SDKExternalUser;
    status: AuthStatus;
    getUser: () => void;
};
declare const AuthContext: react.Context<AuthContextType>;
declare function CrossmintAuthProvider({ embeddedWallets, children, appearance, loginMethods, }: CrossmintAuthProviderProps): react_jsx_runtime.JSX.Element;

export { AuthContext, CrossmintAuthProvider, type CrossmintAuthProviderProps, type CrossmintAuthWalletConfig, type CrossmintCheckoutContext, CrossmintCheckoutProvider, type CrossmintContext, CrossmintEmbeddedCheckout_Alpha, CrossmintNFTCollectionView, CrossmintNFTDetail, CrossmintPayButton, type CrossmintPayButtonReactProps, CrossmintPaymentElement, CrossmintProvider, CrossmintWalletProvider, type LoginMethod, type WalletConfig, WalletContext, useAuth, useCrossmint, useCrossmintCheckout, useRefreshToken, useWallet };
